"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redut_1 = require("../src/redut");
describe('createAction', function () {
    test('should create action creator', function () {
        var action = redut_1.createAction('TEST')();
        expect(action).toBeInstanceOf(Function);
    });
    test('should return action with proper type', function () {
        var action = redut_1.createAction('TEST')();
        expect(action().type).toBe('TEST');
    });
    test('should return action with proper payload', function () {
        var action = redut_1.createAction('TEST')();
        expect(action({ p1: 3, p2: 'str' }).payload).toEqual({ p1: 3, p2: 'str' });
    });
});
describe('createReducer', function () {
    var action1 = redut_1.createAction('INC')(), action2 = redut_1.createAction('DEC')(), actions = { action1: action1, action2: action2 };
    test('should create reducer', function () {
        var reducer = redut_1.createReducer(0, {});
        expect(reducer).toBeInstanceOf(Function);
    });
    test('should pass initial state if state is not specified', function () {
        var _a;
        var reducer = redut_1.createReducer(10, (_a = {},
            _a[action1.type] = function (state) {
                expect(state).toBe(10);
                return state;
            },
            _a));
        reducer(undefined, { type: 'INC', payload: undefined });
    });
    test('should not pass initial state if state is specified', function () {
        var _a;
        var reducer = redut_1.createReducer(10, (_a = {},
            _a[action1.type] = function (state) {
                expect(state).toBe(1);
                return state;
            },
            _a));
        reducer(1, { type: 'INC', payload: undefined });
    });
    test('should return original state if there is no handler for given action', function () {
        var reducer = redut_1.createReducer(0, {});
        expect(reducer(5, { type: 'INC', payload: undefined })).toEqual(5);
    });
    test('should return state according to handler for given action', function () {
        var _a;
        var reducer = redut_1.createReducer(0, (_a = {},
            _a[action1.type] = function (state) { return state + 1; },
            _a[action2.type] = function (state) { return state - 1; },
            _a)), nextState = reducer(undefined, { type: 'INC', payload: undefined });
        expect(nextState).toEqual(1);
        expect(reducer(nextState, { type: 'DEC', payload: undefined })).toEqual(0);
    });
});
//# sourceMappingURL=index.test.js.map