interface Action<TType extends string, TPayload = void> {
    type: TType;
    payload: TPayload;
}
interface ActionWithoutPayloadCreator<TType extends string> {
    type: TType;
    (): Action<TType>;
}
interface ActionWithPayloadCreator<TType extends string, TPayload> {
    type: TType;
    (payload: TPayload): Action<TType, TPayload>;
}
declare type ActionCreator<TType extends string, TPayload = void> = TPayload extends void ? ActionWithoutPayloadCreator<TType> : TPayload extends boolean ? ActionWithPayloadCreator<TType, boolean> : ActionWithPayloadCreator<TType, TPayload>;
declare function createAction<TType extends string>(type: TType): <TPayload>() => ActionCreator<TType, TPayload>;
declare type ActionCreators = Record<string, ActionWithoutPayloadCreator<string> | ActionWithPayloadCreator<string, any>>;
declare type ExtractActionType<TActionCreator extends ActionWithoutPayloadCreator<string> | ActionWithPayloadCreator<string, any>> = ReturnType<TActionCreator> extends Action<infer TType, any> ? TType extends string ? TType : never : never;
declare type Values<T extends object> = T[keyof T];
declare type ExtractActionByType<TAction extends Action<TType>, TType extends string> = TAction extends {
    type: TType;
} ? TAction : never;
declare type ActionOf<TActionCreator extends ActionCreator<string, unknown> | ActionCreators> = TActionCreator extends ActionCreators ? ReturnType<Values<TActionCreator>> : TActionCreator extends ActionCreator<string, unknown> ? ReturnType<TActionCreator> : never;
declare function createReducer<TState, TActionCreators extends ActionCreators>(initialState: TState, actionHandlers: {
    [ActionType in ExtractActionType<Values<TActionCreators>>]?: (state: TState, action: ExtractActionByType<ReturnType<Values<TActionCreators>>, ActionType>) => TState;
}): (state: TState, action: ExtractActionByType<ReturnType<Values<TActionCreators>>, ExtractActionType<Values<TActionCreators>> & string>) => TState;
export { ActionOf, createAction, createReducer };
